// programme de Frederic LETELLIER-COHEN

/////////////////////////////////////////////
// TPG300 Get Press
QString TPG300::getpress(QString identifiant)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  // on vide la memoire
  vider_rs232();

  if(port == NULL) // Il y a un probleme
  {
    // port serie inexistant
    thread.etat = 2;
    return valeur_retour;      
  }

  // envoi de TID
  send_rs232("P" + identifiant);

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
 
  // aucune reception
  if(message == "-2" )
  {
    // envoi de TID
    send_rs232("P" + identifiant);

    // reception de ACK (06) ou NAK (15)
    message = receive_rs232();
  }
 
  if(message.contains("\x06") == FALSE )
  {
    printf ("Erreur - pas de ACK (fonction getpress)\n");    
    return "-1";
  }

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // aucune reception
  if(valeur == "-2" )
  {
    // envoi de <ENQ>
    send_rs232("\x05");

    // reception de la valeur
    valeur = receive_rs232();
  }

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  // on cherche les etats
  QString status = "";
  QChar statuschar = valeur.at(0);
  status.append(statuschar);

  QString pression = valeur.mid(2);

  QString reponse = "";
  if(status == "0") // Measurement data okay
    reponse.append(pression);
  else if(status == "1")
    reponse = "Underrange";
  else if(status == "2")
    reponse = "Overrange";
  else if(status == "3")
    reponse = "Measuring circuit error";
  else if(status == "4")
    reponse = "Measuring circuit switched off";
  else if(status == "5")
    reponse = "No hardware";

  else
  {
    // il y a un probleme avec le TPG300
    reponse = "-1";
  }

  return reponse;
 
}


/////////////////////////////////////////////
// Demande de la version
void TPG300::getversion(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  // on vide la memoire
  vider_rs232();

  if(port == NULL) // Il y a un probleme
  {
    // port serie inexistant
    thread.etat = 2;
    return;      
  }

// 0C F3 00 00 00 00 61 22 00 42 00 C5 	==> 66 : power scale
// 0C F3 00 00 00 00 61 22 00 43 00 C6 	==> 67 : voltage scale
// 0C F3 00 00 00 00 61 22 00 44 00 C7 	==> 68 : current scale

  // envoi de 
// 0C F3 51 12 FF FF EA 62 00 00 03 AD 	
  char toto[12];
  toto[0]= '\x0C';
  toto[1]= '\xF3';
  toto[2]= '\x51';
  toto[3]= '\x12'; 
  toto[4]= '\xFF';
  toto[5]= '\xFF';
  toto[6]= '\xEA';
  toto[7]= '\x62';
  toto[8]= '\x00';
  toto[9]= '\x00';
  toto[10]= '\x03';
  toto[11]= '\xAD';
  send_rs232_bytearray( toto , 12 );

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
 
  // reception de la valeur
  message = receive_rs232();




  // envoi de 
  // 0A LEN
  // F5 ~LEN
  // 00 DST
  // 00 DST
  // 00 SRC
  // 00 SRC
  // 61 CMD
  // 01 CMD
  // 00 CRC
  // 62 CRC
  toto[0]= '\x0A';
  toto[1]= '\xF5';
  toto[2]= '\x00';
  toto[3]= '\x00'; 
  toto[4]= '\x00';
  toto[5]= '\x00';
  toto[6]= '\x61';
  toto[7]= '\x01';
  toto[8]= '\x00';
  toto[9]= '\x62';
  send_rs232_bytearray( toto , 10 );

  // reception de ACK (06) ou NAK (15)
  message = receive_rs232();
 
  // reception de la valeur
  message = receive_rs232();




  // envoi de 
  // 0A LEN
  // F5 ~LEN
  // 00 DST
  // 00 DST
  // 00 SRC
  // 00 SRC
  // 61 CMD
  // 01 CMD
  // 00 CRC
  // 62 CRC
  toto[0]= '\x0A';
  toto[1]= '\xF5';
  toto[2]= '\xFF';
  toto[3]= '\xFF'; 
  toto[4]= '\x00';
  toto[5]= '\x00';
  toto[6]= '\x61';
  toto[7]= '\x01';
  toto[8]= '\x02';
  toto[9]= '\x60';
  send_rs232_bytearray( toto , 10 );

  // reception de ACK (06) ou NAK (15)
  message = receive_rs232();
 
  // reception de la valeur
  message = receive_rs232();





  // envoi de 
// 0C F3 00 00 00 00 61 12 00 04 00 77 	 
  toto[0]= '\x0C';
  toto[1]= '\xF3';
  toto[2]= '\x00';
  toto[3]= '\x00'; 
  toto[4]= '\x00';
  toto[5]= '\x00';
  toto[6]= '\x61';
  toto[7]= '\x12';
  toto[8]= '\x00';
  toto[9]= '\x04';
  toto[10]= '\x00';
  toto[11]= '\x77';
  send_rs232_bytearray( toto , 12 );

  // reception de ACK (06) ou NAK (15)
  message = receive_rs232();
 
  // reception de la valeur
  message = receive_rs232();





  return;
 
}


/////////////////////////////////////////////
// tension U (V)
QString TPG300::gettension(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  // on vide la memoire
  vider_rs232();

  if(port == NULL) // Il y a un probleme
  {
    // port serie inexistant
    thread.etat = 2;
    return valeur_retour;      
  }

  char reception[300];

  // envoi de 
  // 17 E8 00 00 00 00 60 40 00 00 00 00 00 00 00 00 00 00 00 00 00 ==> normal run
  char toto[23];
  toto[0]= '\x17';
  toto[1]= '\xE8';
  toto[2]= '\x00';
  toto[3]= '\x00'; 
  toto[4]= '\x00';
  toto[5]= '\x00';
  toto[6]= '\x60';
  toto[7]= '\x40';
  toto[8]= '\x00';
  toto[9]= '\x00';
  toto[10]= '\x00';
  toto[11]= '\x00';
  toto[12]= '\x00';
  toto[13]= '\x00';
  toto[14]= '\x00';
  toto[15]= '\x00';
  toto[16]= '\x00';
  toto[17]= '\x00';
  toto[18]= '\x00';
  toto[19]= '\x00';
  toto[20]= '\x00';
  toto[21]= '\x00';
  toto[22]= '\xA0';
  send_rs232_bytearray( toto , 23 );

  // reception de ACK (06) ou NAK (15)
  receive_rs232_data(reception);
 
   QByteArray bits_recus ( reception, 39 );
  int bit0, bit1, bit2, bit3;
  unsigned char octet_char;

  // U compris entre 0 et 800 V
  octet_char = bits_recus.data()[10];       
  bit0 = octet_char;
  octet_char = bits_recus.data()[11];       
  bit1 = octet_char;
  octet_char = bits_recus.data()[12];       
  bit2 = octet_char;
  octet_char = bits_recus.data()[13];       
  bit3 = octet_char;
  
  if(bit3 == 63)
    get_pressa1 = conversion3f(bit2);
  else if(bit3 == 64)
    get_pressa1 = conversion40(bit2);
  else if(bit3 == 65)
    get_pressa1 = conversion41(bit2);
  else if(bit3 == 66)
    get_pressa1 = conversion42(bit2);
  else if(bit3 == 67)
    get_pressa1 = conversion43(bit2, bit1);
  else if(bit3 == 68)
    get_pressa1 = conversion44(bit2, bit1);
  else
    get_pressa1 = " > 800";


  // I compris entre 0 et 5000 mA
  octet_char = bits_recus.data()[14];       
  bit0 = octet_char;
  octet_char = bits_recus.data()[15];       
  bit1 = octet_char;
  octet_char = bits_recus.data()[16];       
  bit2 = octet_char;
  octet_char = bits_recus.data()[17];       
  bit3 = octet_char;

  if(bit3 == 63)
    get_pressb1 = conversion3f(bit2);
  else if(bit3 == 64)
    get_pressb1 = conversion40(bit2);
  else if(bit3 == 65)
    get_pressb1 = conversion41(bit2);
  else if(bit3 == 66)
    get_pressb1 = conversion42(bit2);
  else if(bit3 == 67)
    get_pressb1 = conversion43(bit2, bit1);
  else if(bit3 == 68)
    get_pressb1 = conversion44(bit2, bit1);
  else
    get_pressb1 = " > 800 - " + QString::number(bit3);


/*
  // P compris entre 0 et 2000 W
  octet_char = bits_recus.data()[18];       
  bit0 = octet_char;
  octet_char = bits_recus.data()[19];       
  bit1 = octet_char;
  octet_char = bits_recus.data()[20];       
  bit2 = octet_char;
  octet_char = bits_recus.data()[21];       
  bit3 = octet_char;

  if(bit3 == 63)
    get_pressa2 = conversion3f(bit2);
  else if(bit3 == 64)
    get_pressa2 = conversion40(bit2);
  else if(bit3 == 65)
    get_pressa2 = conversion41(bit2);
  else if(bit3 == 66)
    get_pressa2 = conversion42(bit2);
  else if(bit3 == 67)
    get_pressa2 = conversion43(bit2, bit1);
  else if(bit3 == 68)
    get_pressa2 = conversion44(bit2, bit1);
  else
    get_pressa2 = " > 800 - "  + QString::number(bit3);
*/

  return valeur_retour;
}


/////////////////////////////////////////////
// courant I (A)
QString TPG300::getcourant(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  // on vide la memoire
  vider_rs232();

  if(port == NULL) // Il y a un probleme
  {
    // port serie inexistant
    thread.etat = 2;
    return valeur_retour;      
  }

  char reception[300];

  // envoi de 
  // 17 E8 00 00 00 00 60 40 00 00 00 00 00 00 00 00 00 00 00 00 00 ==> normal run
  char toto[23];
  toto[0]= '\x17';
  toto[1]= '\xE8';
  toto[2]= '\x00';
  toto[3]= '\x00'; 
  toto[4]= '\x00';
  toto[5]= '\x00';
  toto[6]= '\x60';
  toto[7]= '\x40';
  toto[8]= '\x00';
  toto[9]= '\x00';
  toto[10]= '\x00';
  toto[11]= '\x00';
  toto[12]= '\x00';
  toto[13]= '\x00';
  toto[14]= '\x00';
  toto[15]= '\x00';
  toto[16]= '\x00';
  toto[17]= '\x00';
  toto[18]= '\x00';
  toto[19]= '\x00';
  toto[20]= '\x00';
  toto[21]= '\x00';
  toto[22]= '\xA0';
  send_rs232_bytearray( toto , 23 );

  // reception de ACK (06) ou NAK (15)
  receive_rs232_data(reception);
 
  int bit0, bit1, bit2, bit3;
  bit0 = reception[14];
  bit1 = reception[15];
  bit2 = reception[16];
  bit3 = reception[17];

  valeur_retour = QString::number(bit1) + " - " + QString::number(bit2) + " - " + QString::number(bit3);

  return valeur_retour;
}

/////////////////////////////////////////////
// puissance P (W)
QString TPG300::getpuissance(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  // on vide la memoire
  vider_rs232();

  if(port == NULL) // Il y a un probleme
  {
    // port serie inexistant
    thread.etat = 2;
    return valeur_retour;      
  }

  char reception[300];

  // envoi de 
  // 17 E8 00 00 00 00 60 40 00 00 00 00 00 00 00 00 00 00 00 00 00 ==> normal run
  char toto[23];
  toto[0]= '\x17';
  toto[1]= '\xE8';
  toto[2]= '\x00';
  toto[3]= '\x00'; 
  toto[4]= '\x00';
  toto[5]= '\x00';
  toto[6]= '\x60';
  toto[7]= '\x40';
  toto[8]= '\x00';
  toto[9]= '\x00';
  toto[10]= '\x00';
  toto[11]= '\x00';
  toto[12]= '\x00';
  toto[13]= '\x00';
  toto[14]= '\x00';
  toto[15]= '\x00';
  toto[16]= '\x00';
  toto[17]= '\x00';
  toto[18]= '\x00';
  toto[19]= '\x00';
  toto[20]= '\x00';
  toto[21]= '\x00';
  toto[22]= '\xA0';
  send_rs232_bytearray( toto , 23 );

  // reception de ACK (06) ou NAK (15)
  receive_rs232_data(reception);
 
  int bit0, bit1, bit2, bit3;
  bit0 = reception[18];
  bit1 = reception[19];
  bit2 = reception[20];
  bit3 = reception[21];

  valeur_retour = QString::number(bit1) + " - " + QString::number(bit2) + " - " + QString::number(bit3);

  return valeur_retour;
}




/////////////////////////////////////////////
// [0 - 2]
QString TPG300::conversion3f(int valeur)
{
  if(valeur == 255)
    return "2";
  else
    return "1";

  return "error";
}

/////////////////////////////////////////////
// [3 - 8]
QString TPG300::conversion40(int valeur)
{
  if(valeur <= 63)
    return "3";
  else if(valeur <=127)
    return "4";
  else if(valeur <=159)
    return "5";
  else if(valeur <=191)
    return "6";
  else if(valeur <=223)
    return "7";
  else if(valeur <=255)
    return "8";

  return "error";
}

/////////////////////////////////////////////
// [9 - 32]
QString TPG300::conversion41(int valeur)
{
  int i = 9;
  int j = 15;

  if(valeur <= 127)
  {
    while(j < valeur)
    {
       j = j + 16;
       i++;
    } 
    return QString::number(i);
  }

  i = 16;
  j = 127;
  if(valeur <= 255)
  {
    while(j < valeur)
    {
       j = j + 8;
       i++;
    } 
    return QString::number(i);
  }

  return "error";

}

/////////////////////////////////////////////
// [33 - 128]
QString TPG300::conversion42(int valeur)
{

  int i = 33;
  int j = 3;

  if(valeur <= 127)
  {
    while(j < valeur)
    {
       j = j + 4;
       i++;
    } 
    return QString::number(i);
  }

  i = 64;
  j = 127;
  if(valeur <= 255)
  {
    while(j < valeur)
    {
       j = j + 2;
       i++;
    } 
    return QString::number(i);
  }

  return "error";
}

/////////////////////////////////////////////
// [129 - 512]
QString TPG300::conversion43(int valeur1, int valeur2)
{

  int i = 129;
  int j = 0;

  if(valeur1 <= 127)
  {
    while(j < valeur1)
    {
       j++;
       i++;
    } 
    return QString::number(i);
  }

  i = 256;
  j = 127;
  if(valeur1 <= 255)
  {
    while(j < valeur1)
    {
       j++;
       i = i + 2;
    }
    if(valeur2 ==  127)
      i = i-1;
    return QString::number(i);
  }

  return "error";
}

/////////////////////////////////////////////
// [513 - 800]
QString TPG300::conversion44(int valeur1, int valeur2)
{

  int i = 513;
  int j = 0;

  if(valeur1 <= 127)
  {
    while(j < valeur1)
    {
       j++;
       i = i + 4;
    } 
    if(valeur2 ==  255)
      i = i-1;
    else if(valeur2 ==  191)
      i = i-2;
    else if(valeur2 ==  127)
      i = i-3;
    return QString::number(i);
  }

  return "error";
}




/*
/////////////////////////////////////////////
// TPG300 Programm number
QString TPG300::programmnumber(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
  {
    printf ("Erreur - port serie inexistant\n");
    return valeur_retour;        
  }

  // envoi de PNR
  send_rs232("PNR");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  return valeur; 
}


/////////////////////////////////////////////
// TPG300 Code lock
QString TPG300::codelock(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
  {
    printf ("Erreur - port serie inexistant\n");
    return valeur_retour;        
  }

  // envoi de COD
  send_rs232("COD");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  return valeur; 
}

/////////////////////////////////////////////
// TPG300 Error Status
QString TPG300::errorstatus(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
  {
    printf ("Erreur - port serie inexistant\n");
    return valeur_retour;        
  }

  // envoi de ERR
  send_rs232("ERR");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  if(valeur == "0000")
    valeur = "No error";
  else if(valeur == "1000")
    valeur = "TPG error (see display on the front panel)";
  else if(valeur == "0100")
    valeur = "Hardware not installed";
  else if(valeur == "0010")
    valeur = "Invalid parameter";
  else if(valeur == "0001")
    valeur = "Syntax error";

  return valeur; 
}


/////////////////////////////////////////////
// TPG300 Display Unit
QString TPG300::displayunit(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
  {
    printf ("Erreur - port serie inexistant\n");
    return valeur_retour;        
  }

  // envoi de UNI
  send_rs232("UNI");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  if(valeur == "1")
    valeur = "mbar";
  else if(valeur == "2")
    valeur = "Torr";
  else if(valeur == "3")
    valeur = "Pa";

  return valeur; 
}


/////////////////////////////////////////////
// TPG300 underrange control
QString TPG300::underrangecontrol(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
  {
    printf ("Erreur - port serie inexistant\n");
    return valeur_retour;        
  }

  // envoi de UNI
  send_rs232("UNI");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  if(valeur == "0")
    valeur = "Off";
  else if(valeur == "1")
    valeur = "On";

  return valeur; 
}

/////////////////////////////////////////////
// TPG300 Set Point
QString TPG300::setpoint(QString identifiant)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
  {
    printf ("Erreur - port serie inexistant\n");
    return valeur_retour;        
  }

  // envoi de SP
  send_rs232("SP" + identifiant);

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  // on cherche les virgules
  int virgule1 = valeur.indexOf(",", 0);
  int virgule2 = valeur.indexOf(",", virgule1+1);



  QString phrase;
  phrase = "lower threshold : " +   valeur.mid(0, virgule1) + " - upper threshold : " + valeur.mid(virgule1+1, virgule2-virgule1-1)  + " - Switching function assignment : " + valeur.mid(virgule2+1, 1);



  return phrase; 
}

/////////////////////////////////////////////
// TPG300 Switching function status
QString TPG300::setpointswitching(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
  {
    printf ("Erreur - port serie inexistant\n");
    return valeur_retour;        
  }

  // envoi de SPS
  send_rs232("SPS");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  // on cherche les etats
  QString etat1;
  QString etat2;
  QString etat3;
  QString etat4;
  QString etat5;
  QString etat6;
  if(QString::QString(valeur.at(0)) == "0")
    etat1 = "off";
  else if(QString::QString(valeur.at(0)) == "1")
    etat1 = "on";
  if(QString::QString(valeur.at(2)) == "0")
    etat2 = "off";
  else if(QString::QString(valeur.at(2)) == "1")
    etat2 = "on";
  if(QString::QString(valeur.at(4)) == "0")
    etat3 = "off";
  else if(QString::QString(valeur.at(4)) == "1")
    etat3 = "on";
  if(QString::QString(valeur.at(6)) == "0")
    etat4 = "off";
  else if(QString::QString(valeur.at(6)) == "1")
    etat4 = "on";
  if(QString::QString(valeur.at(8)) == "0")
    etat5 = "off";
  else if(QString::QString(valeur.at(8)) == "1")
    etat5 = "on";
  if(QString::QString(valeur.at(10)) == "0")
    etat6 = "off";
  else if(QString::QString(valeur.at(10)) == "1")
    etat6 = "on";

  QString phrase;
  phrase = "Switching function 1 : " + etat1 + " - Switching function 2 : " + etat2 + " - Switching function 3 : " + etat3 + " - Switching function 4 : " + etat4 + " - Switching function A : " + etat5 + " - Switching function B : " + etat6;

  return phrase; 
}


/////////////////////////////////////////////
// TPG300 Sensor On/Off
QString TPG300::sensoronoff(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
  {
    printf ("Erreur - port serie inexistant\n");
    return valeur_retour;        
  }

  // envoi de SEN
  send_rs232("SEN");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  // on cherche les etats
  QString etat1;
  QString etat2;
  QString etat3;
  QString etat4;

  if(QString::QString(valeur.at(0)) == "0")
    etat1 = "no measuring channel";
  else if(QString::QString(valeur.at(0)) == "1")
    etat1 = "off";
  else if(QString::QString(valeur.at(0)) == "2")
    etat1 = "automatic";
  else if(QString::QString(valeur.at(0)) == "3")
    etat1 = "on";

  if(QString::QString(valeur.at(2)) == "0")
    etat2 = "no measuring channel";
  else if(QString::QString(valeur.at(2)) == "1")
    etat2 = "off";
  else if(QString::QString(valeur.at(2)) == "2")
    etat2 = "automatic";
  else if(QString::QString(valeur.at(2)) == "3")
    etat2 = "on";

  if(QString::QString(valeur.at(4)) == "0")
    etat3 = "no measuring channel";
  else if(QString::QString(valeur.at(4)) == "1")
    etat3 = "off";
  else if(QString::QString(valeur.at(4)) == "2")
    etat3 = "automatic";
  else if(QString::QString(valeur.at(4)) == "3")
    etat3 = "on";

  if(QString::QString(valeur.at(6)) == "0")
    etat4 = "no measuring channel";
  else if(QString::QString(valeur.at(6)) == "1")
    etat4 = "off";
  else if(QString::QString(valeur.at(6)) == "2")
    etat4 = "automatic";
  else if(QString::QString(valeur.at(6)) == "3")
    etat4 = "on";


  QString phrase;
  phrase = "Measuring circuit A1 : " + etat1 + " - Measuring circuit A2 : " + etat2 + " - Measuring circuit B1 : " + etat3 + " - Measuring circuit B2 : " + etat4;

  return phrase; 
}


/////////////////////////////////////////////
// TPG300 Filter Time
QString TPG300::filtertime(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
  {
    printf ("Erreur - port serie inexistant\n");
    return valeur_retour;        
  }

  // envoi de FIL
  send_rs232("FIL");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  // on cherche les etats
  QString etat1;
  QString etat2;
  QString etat3;
  QString etat4;

  if(QString::QString(valeur.at(0)) == "1")
    etat1 = "fast";
  else if(QString::QString(valeur.at(0)) == "2")
    etat1 = "medium";
  else if(QString::QString(valeur.at(0)) == "3")
    etat1 = "slow";

  if(QString::QString(valeur.at(2)) == "1")
    etat2 = "fast";
  else if(QString::QString(valeur.at(2)) == "2")
    etat2 = "medium";
  else if(QString::QString(valeur.at(2)) == "3")
    etat2 = "slow";

  if(QString::QString(valeur.at(4)) == "1")
    etat3 = "fast";
  else if(QString::QString(valeur.at(4)) == "2")
    etat3 = "medium";
  else if(QString::QString(valeur.at(4)) == "3")
    etat3 = "slow";

  if(QString::QString(valeur.at(6)) == "1")
    etat4 = "fast";
  else if(QString::QString(valeur.at(6)) == "2")
    etat4 = "medium";
  else if(QString::QString(valeur.at(6)) == "3")
    etat4 = "slow";


  QString phrase;
  phrase = "Measuring circuit A1 : " + etat1 + " - Measuring circuit A2 : " + etat2 + " - Measuring circuit B1 : " + etat3 + " - Measuring circuit B2 : " + etat4;

  return phrase; 
}


/////////////////////////////////////////////
// TPG300 Slot ID's
QString TPG300::slotids(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
  {
    printf ("Erreur - port serie inexistant\n");
    return valeur_retour;        
  }

  // envoi de TID
  send_rs232("TID");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  // on cherche les virgules
  int virgule1 = valeur.indexOf(",", 0);
  int virgule2 = valeur.indexOf(",", virgule1+1);

  // on cherche les etats
  QString etat1 = valeur.mid(0, virgule1);
  QString etat2 = valeur.mid(virgule1+1, virgule2-virgule1-1);
  QString etat3 = valeur.mid(virgule2+1);

  QString phrase;
  phrase = "Identification slot A : " + etat1 + " - Identification slot B : " + etat2 + " - Identification slot C : " + etat3;

  return phrase; 
}


/////////////////////////////////////////////
// TPG300 Get Press
QString TPG300::getpress(QString identifiant)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
  {
    printf ("Erreur - port serie inexistant\n");
    return valeur_retour;        
  }

  // envoi de TID
  send_rs232("P" + identifiant);

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  // on cherche les etats
  QString status;
  status = QString::QString(valeur.at(0));
  QString pression = valeur.mid(2);

  QString reponse;
  if(status == "0") // Measurement data okay
    reponse = pression;
  else if(status == "1")
    reponse = "Underrange";
  else if(status == "2")
    reponse = "Overrange";
  else if(status == "3")
    reponse = "Measuring circuit error";
  else if(status == "4")
    reponse = "Measuring circuit switched off";
  else if(status == "5")
    reponse = "No hardware";

  return reponse;
 
}



*/
